Index: tests/phpunit/data/formatting/sizzle.js
===================================================================
--- tests/phpunit/data/formatting/sizzle.js	(revision 38908)
+++ tests/phpunit/data/formatting/sizzle.js	(working copy)
@@ -17,7 +17,7 @@
 	rNonWord = /\W/;
 
 // Here we check if the JavaScript engine is using some sort of
-// optimization where it does not always call our comparision
+// optimization where it does not always call our comparison
 // function. If that is the case, discard the hasDuplicate value.
 //   Thus far that includes Google Chrome.
 [0, 0].sort(function() {
Index: tests/phpunit/data/formatting/whole-posts.php
===================================================================
--- tests/phpunit/data/formatting/whole-posts.php	(revision 38908)
+++ tests/phpunit/data/formatting/whole-posts.php	(working copy)
@@ -719,7 +719,7 @@
 <img class="alignright" src="http://www.example.com/postimages/2013/philipmetroid.jpg" alt="" width="50" height="50" />
 <p class="triangle-right right">PLOT TWIST</p>
 <img class="alignleft" src="http://www.example.com/postimages/2013/aarone.jpeg" alt="" width="50" height="50" />
-<p class="triangle-right lefttwo">Video of famous director eating grilled Sandwich while swiping with greasy fingers.</p>
+<p class="triangle-right lefttwo">Video of famous director eating grilled Sandwhich while swiping with greasy fingers.</p>
 <img class="alignright" src="http://www.example.com/postimages/2013/philipmetroid.jpg" alt="" width="50" height="50" />
 <p class="triangle-right right">WHOA</p>
 <img class="alignleft" src="http://www.example.com/postimages/2013/bobm.jpeg" alt="" width="50" height="50" />
Index: tests/phpunit/data/formatting/xssAttacks.xml
===================================================================
--- tests/phpunit/data/formatting/xssAttacks.xml	(revision 38908)
+++ tests/phpunit/data/formatting/xssAttacks.xml	(working copy)
@@ -689,7 +689,7 @@
 	<attack> 
 		<name>Extraneous Open Brackets</name> 
 		<code>&lt;&lt;SCRIPT&gt;alert(&quot;XSS&quot;);//&lt;&lt;/SCRIPT&gt;</code> 
-		<desc>(Submitted by Franz Sedlmaier http://www.pilorz.net/).  This XSS vector could defeat certain detection engines that work by first using matching pairs of open and close angle brackets and then by doing a comparison of the tag inside, instead of a more efficient algorythm like Boyer-Moore (http://www.cs.utexas.edu/users/moore/best-ideas/string-searching/) that looks for entire string matches of the open angle bracket and associated tag (post de-obfuscation, of course).  The double slash comments out the ending extraneous bracket to supress a JavaScript error.</desc> 
+		<desc>(Submitted by Franz Sedlmaier http://www.pilorz.net/).  This XSS vector could defeat certain detection engines that work by first using matchingg pairs of open and close angle brackets and then by doing a comparison of the tag inside, instead of a more efficient algorythm like Boyer-Moore (http://www.cs.utexas.edu/users/moore/best-ideas/string-searching/) that looks for entire string matches of the open angle bracket and associated tag (post de-obfuscation, of course).  The double slash comments out the ending extraneous bracket to suppress a JavaScript error.</desc> 
 		<label>Embedded Character Attacks</label> 
 		<browser>Browser support: [&lt;span class=&quot;s&quot;&gt;IE6.0&lt;/span&gt;|&lt;span class=&quot;s&quot;&gt;NS8.1-IE&lt;/span&gt;] [&lt;span class=&quot;s&quot;&gt;NS8.1-G&lt;/span&gt;|&lt;span class=&quot;s&quot;&gt;FF1.5&lt;/span&gt;] [&lt;span class=&quot;s&quot;&gt;O8.54&lt;/span&gt;]</browser> 
 	</attack> 
@@ -969,7 +969,7 @@
 	<attack> 
 		<name>Filter Evasion 2</name> 
 		<code>&lt;SCRIPT a=&quot;>&apos;>&quot; SRC=&quot;http://ha.ckers.org/xss.js&quot;&gt;&lt;/SCRIPT&gt;</code> 
-		<desc>Here&apos;s an XSS example that bets on the fact that the regex won&apos;t catch a matching pair of quotes but will rather find any quotes to terminate a parameter string improperly.</desc> 
+		<desc>Here&apos;s an XSS example that bets on the fact that the regex won&apos;t catch a matchingg pair of quotes but will rather find any quotes to terminate a parameter string improperly.</desc> 
 		<label>XSS w/HTML Quote Encapsulation</label> 
 		<browser>Browser support: [&lt;span class=&quot;s&quot;&gt;IE6.0&lt;/span&gt;|&lt;span class=&quot;s&quot;&gt;NS8.1-IE&lt;/span&gt;] [&lt;span class=&quot;s&quot;&gt;NS8.1-G&lt;/span&gt;|&lt;span class=&quot;s&quot;&gt;FF1.5&lt;/span&gt;] [&lt;span class=&quot;s&quot;&gt;O8.54&lt;/span&gt;]</browser> 
 	</attack>
Index: tests/phpunit/data/pomo/de_DE-2.8.mo
===================================================================
Cannot display: file marked as a binary type.
svn:mime-type = application/octet-stream
Index: tests/phpunit/data/pomo/overload.mo
===================================================================
Cannot display: file marked as a binary type.
svn:mime-type = application/octet-stream
Index: tests/phpunit/includes/utils.php
===================================================================
--- tests/phpunit/includes/utils.php	(revision 38908)
+++ tests/phpunit/includes/utils.php	(working copy)
@@ -315,7 +315,7 @@
 	echo "\n";
 }
 
-// mask out any input fields matching the given name
+// mask out any input fields matchingg the given name
 function mask_input_value($in, $name='_wpnonce') {
 	return preg_replace('@<input([^>]*) name="'.preg_quote($name).'"([^>]*) value="[^>]*" />@', '<input$1 name="'.preg_quote($name).'"$2 value="***" />', $in);
 }
Index: tests/phpunit/tests/cache.php
===================================================================
--- tests/phpunit/tests/cache.php	(revision 38908)
+++ tests/phpunit/tests/cache.php	(working copy)
@@ -285,7 +285,7 @@
 		global $wp_object_cache;
 
 		if ( wp_using_ext_object_cache() ) {
-			// External caches will contain property values that contain non-matching resource IDs
+			// External caches will contain property values that contain non-matchingg resource IDs
 			$this->assertInstanceOf( 'WP_Object_Cache', $wp_object_cache  );
 		} else {
 			$this->assertEquals( $wp_object_cache, $new_blank_cache_object );
Index: tests/phpunit/tests/cron.php
===================================================================
--- tests/phpunit/tests/cron.php	(revision 38908)
+++ tests/phpunit/tests/cron.php	(working copy)
@@ -44,7 +44,7 @@
 		$args = array('foo');
 
 		wp_schedule_single_event( $timestamp, $hook, $args );
-		// this returns the timestamp only if we provide matching args
+		// this returns the timestamp only if we provide matchingg args
 		$this->assertEquals( $timestamp, wp_next_scheduled($hook, $args) );
 		// these don't match so return nothing
 		$this->assertEquals( false, wp_next_scheduled($hook) );
@@ -75,7 +75,7 @@
 		$args = array('foo');
 
 		wp_schedule_event( $timestamp, 'hourly', $hook, $args );
-		// this returns the timestamp only if we provide matching args
+		// this returns the timestamp only if we provide matchingg args
 		$this->assertEquals( $timestamp, wp_next_scheduled($hook, $args) );
 		// these don't match so return nothing
 		$this->assertEquals( false, wp_next_scheduled($hook) );
Index: tests/phpunit/tests/dependencies/styles.php
===================================================================
--- tests/phpunit/tests/dependencies/styles.php	(revision 38908)
+++ tests/phpunit/tests/dependencies/styles.php	(working copy)
@@ -112,7 +112,7 @@
 	}
 
 	/**
-	 * Test if inline styles work with concatination
+	 * Test if inline styles work with concatenation
 	 * @global WP_Styles $wp_styles
 	 * @ticket 24813
 	 */
Index: tests/phpunit/tests/formatting/Smilies.php
===================================================================
--- tests/phpunit/tests/formatting/Smilies.php	(revision 38908)
+++ tests/phpunit/tests/formatting/Smilies.php	(working copy)
@@ -254,7 +254,7 @@
 			smilies_init();
 		}
 
-		$orig_trans = $wpsmiliestrans; // save original tranlations array
+		$orig_trans = $wpsmiliestrans; // save original translations array
 
 		$wpsmiliestrans = array (
 		  ':)' => 'simple-smile.png'
Index: tests/phpunit/tests/http/base.php
===================================================================
--- tests/phpunit/tests/http/base.php	(revision 38908)
+++ tests/phpunit/tests/http/base.php	(working copy)
@@ -186,7 +186,7 @@
 	 * @ticket 11888
 	 */
 	function test_send_headers() {
-		// Test that the headers sent are recieved by the server
+		// Test that the headers sent are received by the server
 		$headers = array('test1' => 'test', 'test2' => 0, 'test3' => '');
 		$res = wp_remote_request( $this->redirection_script . '?header-check', array('headers' => $headers) );
 
Index: tests/phpunit/tests/image/meta.php
===================================================================
--- tests/phpunit/tests/image/meta.php	(revision 38908)
+++ tests/phpunit/tests/image/meta.php	(working copy)
@@ -88,7 +88,7 @@
 	function test_exif_error() {
 
 		// https://core.trac.wordpress.org/ticket/6571
-		// this triggers a warning mesage when reading the exif block
+		// this triggers a warning message when reading the exif block
 		$out = wp_read_image_metadata(DIR_TESTDATA.'/images/waffles.jpg');
 
 		$this->assertEquals(0, $out['aperture']);
Index: tests/phpunit/tests/mail.php
===================================================================
--- tests/phpunit/tests/mail.php	(revision 38908)
+++ tests/phpunit/tests/mail.php	(working copy)
@@ -102,7 +102,7 @@
 
 		wp_mail( $to, $subject, $message, $headers );
 
-		// WordPress 3.2 and later correctly split the address into the two parts and send them seperately to PHPMailer
+		// WordPress 3.2 and later correctly split the address into the two parts and send them separately to PHPMailer
 		// Earlier versions of PHPMailer were not touchy about the formatting of these arguments.
 
 		//retrieve the mailer instance
@@ -126,7 +126,7 @@
 
 		wp_mail( $to, $subject, $message );
 
-		// WordPress 3.2 and later correctly split the address into the two parts and send them seperately to PHPMailer
+		// WordPress 3.2 and later correctly split the address into the two parts and send them separately to PHPMailer
 		// Earlier versions of PHPMailer were not touchy about the formatting of these arguments.
 		$mailer = tests_retrieve_phpmailer_instance();
 		$this->assertEquals( 'address@tld.com',                   $mailer->get_recipient( 'to' )->address );
Index: tests/phpunit/tests/multisite/site.php
===================================================================
--- tests/phpunit/tests/multisite/site.php	(revision 38908)
+++ tests/phpunit/tests/multisite/site.php	(working copy)
@@ -960,7 +960,7 @@
 	 * @param string $value          The sanitized option value.
 	 * @param string $option         The option name.
 	 * @param string $original_value The original value passed to the function.
-	 * @return string The orginal value.
+	 * @return string The original value.
 	 */
 	function filter_allow_unavailable_languages( $value, $option, $original_value ) {
 		return $original_value;
Index: tests/phpunit/tests/post/objects.php
===================================================================
--- tests/phpunit/tests/post/objects.php	(revision 38908)
+++ tests/phpunit/tests/post/objects.php	(working copy)
@@ -28,7 +28,7 @@
 		$this->assertEquals( 'dummy', get_post_meta( $id, 'post_type', true ) );
 		$this->assertEquals( 'post', $post->post_type );
 
-		// Excercise the output argument
+		// Exercise the output argument
 		$post = get_post( $id, ARRAY_A );
 		$this->assertInternalType( 'array', $post );
 		$this->assertEquals( 'post', $post[ 'post_type' ] );
Index: tests/phpunit/tests/query/search.php
===================================================================
--- tests/phpunit/tests/query/search.php	(revision 38908)
+++ tests/phpunit/tests/query/search.php	(working copy)
@@ -227,7 +227,7 @@
 			'post_status' => 'publish',
 			'post_title' => '0',
 			'post_content' => 'this post contains zeroes',
-			'post_excerpt' => 'this post containts zeroes',
+			'post_excerpt' => 'this post contains zeroes',
 		) );
 
 		$q = new WP_Query( array(
@@ -330,7 +330,7 @@
 	}
 
 	/**
-	 * Unfiltered search queries for attachment post types should not inlcude
+	 * Unfiltered search queries for attachment post types should not include
 	 * filenames to ensure the postmeta JOINs don't happen on the front end.
 	 *
 	 * @ticket 22744
Index: tests/phpunit/tests/user/capabilities.php
===================================================================
--- tests/phpunit/tests/user/capabilities.php	(revision 38908)
+++ tests/phpunit/tests/user/capabilities.php	(working copy)
@@ -671,7 +671,7 @@
 	}
 
 	function test_role_add_cap() {
-		// change the capabilites associated with a role and make sure the change is reflected in has_cap()
+		// change the capabilities associated with a role and make sure the change is reflected in has_cap()
 
 		global $wp_roles;
 		$role_name = rand_str();
@@ -711,7 +711,7 @@
 	}
 
 	function test_role_remove_cap() {
-		// change the capabilites associated with a role and make sure the change is reflected in has_cap()
+		// change the capabilities associated with a role and make sure the change is reflected in has_cap()
 
 		global $wp_roles;
 		$role_name = rand_str();

Index: tests/phpunit/tests/rest-api.php
===================================================================
--- tests/phpunit/tests/rest-api.php	(revision 38908)
+++ tests/phpunit/tests/rest-api.php	(working copy)
@@ -256,9 +256,9 @@
 	}
 
 	/**
 	 * The 'methods' arg should a comma seperated string.
 	 */
-	public function test_route_method_comma_seperated() {
+	public function test_route_method_comma_separated() {
 		register_rest_route( 'test-ns', '/test', array(
 			'methods'  => 'GET,POST',
 			'callback' => '__return_null',
@@ -256,9 +256,9 @@
 
 	/**
-	 * The 'methods' arg should a comma seperated string.
+	 * The 'methods' arg should a comma separated string.
 	 */